@@ -19,6 +19,8 @@
 #include "localisation.h"
 
 #include <glib.h>
+#include <glib/gprintf.h>
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <tablet-browser-interface.h>
 #include <sys/socket.h>
